@@ -39,7 +39,7 @@ describe Thor::Actions do
     end
 
     it "when behavior is set to skip, overwrite options" do
-      runner = MyCounter.new([1], %w[--force], :behavior => :skip)
+      runner = MyCounter.new([1], %w(--force), :behavior => :skip)
       expect(runner.behavior).to eq(:invoke)
       expect(runner.options.force).not_to be true
       expect(runner.options.skip).to be true
@@ -86,6 +86,21 @@ describe Thor::Actions do
         expect(runner.relative_to_original_destination_root("/test/file")).to eq("/test/file")
       end
 
+      it "doesn't remove the root path from the absolute path if it is not at the begining" do
+        runner.destination_root = "/app"
+        expect(runner.relative_to_original_destination_root("/something/app/project")).to eq("/something/app/project")
+      end
+
+      it "doesn't removes the root path from the absolute path only if it is only the partial name of the directory" do
+        runner.destination_root = "/app"
+        expect(runner.relative_to_original_destination_root("/application/project")).to eq("/application/project")
+      end
+
+      it "removes the root path from the absolute path only once" do
+        runner.destination_root = "/app"
+        expect(runner.relative_to_original_destination_root("/app/app/project")).to eq("app/project")
+      end
+
       it "does not fail with files containing regexp characters" do
         runner = MyCounter.new([1], {}, :destination_root => File.join(destination_root, "fo[o-b]ar"))
         expect(runner.relative_to_original_destination_root("bar")).to eq("bar")
@@ -121,7 +136,7 @@ describe Thor::Actions do
 
       it "finds a template inside the source path" do
         expect(runner.find_in_source_paths("doc")).to eq(File.expand_path("doc", source_root))
-        expect { runner.find_in_source_paths("README") }.to raise_error
+        expect { runner.find_in_source_paths("README") }.to raise_error(Thor::Error, /Could not find "README" in any of your source paths./)
 
         new_path = File.join(source_root, "doc")
         runner.instance_variable_set(:@source_paths, nil)
@@ -204,7 +219,7 @@ describe Thor::Actions do
 
   describe "#apply" do
     before do
-      @template = <<-TEMPLATE
+      @template = <<-TEMPLATE.dup
         @foo = "FOO"
         say_status :cool, :padding
       TEMPLATE
@@ -253,25 +268,53 @@ describe Thor::Actions do
   end
 
   describe "#run" do
-    before do
-      expect(runner).to receive(:system).with("ls")
+    describe "when not pretending" do
+      before do
+        expect(runner).to receive(:system).with("ls")
+      end
+
+      it "executes the command given" do
+        action :run, "ls"
+      end
+
+      it "logs status" do
+        expect(action(:run, "ls")).to eq("         run  ls from \".\"\n")
+      end
+
+      it "does not log status if required" do
+        expect(action(:run, "ls", :verbose => false)).to be_empty
+      end
+
+      it "accepts a color as status" do
+        expect(runner.shell).to receive(:say_status).with(:run, 'ls from "."', :yellow)
+        action :run, "ls", :verbose => :yellow
+      end
     end
 
-    it "executes the command given" do
-      action :run, "ls"
+    describe "aborting on failure" do
+      it "aborts when abort_on_failure is given and command fails" do
+        expect { action :run, "false", :abort_on_failure => true }.to raise_error(SystemExit)
+      end
+
+      it "suceeds when abort_on_failure is given and command succeeds" do
+        expect { action :run, "true", :abort_on_failure => true }.not_to raise_error
+      end
+
+      it "aborts when abort_on_failure is given, capture is given and command fails" do
+        expect { action :run, "false", :abort_on_failure => true, :capture => true }.to raise_error(SystemExit)
+      end
+
+      it "suceeds when abort_on_failure is given and command succeeds" do
+        expect { action :run, "true", :abort_on_failure => true, :capture => true }.not_to raise_error
+      end
     end
 
-    it "logs status" do
-      expect(action(:run, "ls")).to eq("         run  ls from \".\"\n")
-    end
-
-    it "does not log status if required" do
-      expect(action(:run, "ls", :verbose => false)).to be_empty
-    end
-
-    it "accepts a color as status" do
-      expect(runner.shell).to receive(:say_status).with(:run, 'ls from "."', :yellow)
-      action :run, "ls", :verbose => :yellow
+    describe "when pretending" do
+      it "doesn't execute the command" do
+        runner = MyCounter.new([1], %w(--pretend))
+        expect(runner).not_to receive(:system)
+        runner.run("ls", :verbose => false)
+      end
     end
   end
 
