@@ -100,84 +100,91 @@ BoringVendorProvidedCLI.register(
   ExcitingPluginCLI,
   "exciting",
   "do exciting things",
-  "Various non-boring actions")
+  "Various non-boring actions"
+)
 
 BoringVendorProvidedCLI.register(
   SuperSecretPlugin,
   "secret",
   "secret stuff",
   "Nothing to see here. Move along.",
-  :hide => true)
+  :hide => true
+)
 
 BoringVendorProvidedCLI.register(
   GroupPlugin,
   "groupwork",
   "Do a bunch of things in a row",
-  "purple monkey dishwasher")
+  "purple monkey dishwasher"
+)
 
 BoringVendorProvidedCLI.register(
   CompatibleWith19Plugin,
   "zoo",
   "zoo [-w animal]",
-  "Shows a provided animal or just zebra")
+  "Shows a provided animal or just zebra"
+)
 
 BoringVendorProvidedCLI.register(
   PluginWithDefault,
   "say",
   "say message",
-  "subcommands ftw")
+  "subcommands ftw"
+)
 
 BoringVendorProvidedCLI.register(
   PluginWithDefaultMultipleArguments,
   "say_multiple",
   "say message",
-  "subcommands ftw")
+  "subcommands ftw"
+)
 
 BoringVendorProvidedCLI.register(
   PluginWithDefaultcommandAndDeclaredArgument,
   "say_argument",
   "say message",
-  "subcommands ftw")
+  "subcommands ftw"
+)
 
 BoringVendorProvidedCLI.register(SubcommandWithDefault,
   "subcommand", "subcommand", "Run subcommands")
 
 describe ".register-ing a Thor subclass" do
   it "registers the plugin as a subcommand" do
-    fireworks_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[exciting fireworks]) }
+    fireworks_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(exciting fireworks)) }
     expect(fireworks_output).to eq("kaboom!\n")
   end
 
   it "includes the plugin's usage in the help" do
-    help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[help]) }
+    help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(help)) }
     expect(help_output).to include("do exciting things")
   end
 
   context "with a default command," do
     it "invokes the default command correctly" do
-      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[say hello]) }
+      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(say hello)) }
       expect(output).to include("hello")
     end
 
     it "invokes the default command correctly with multiple args" do
-      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[say_multiple hello adam]) }
+      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(say_multiple hello adam)) }
       expect(output).to include("hello")
       expect(output).to include("adam")
     end
 
     it "invokes the default command correctly with a declared argument" do
-      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[say_argument hello]) }
+      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(say_argument hello)) }
       expect(output).to include("hello")
     end
 
     it "displays the subcommand's help message" do
-      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[subcommand help]) }
+      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(subcommand help)) }
       expect(output).to include("default subcommand")
       expect(output).to include("subcommand with argument")
     end
 
     it "invokes commands with their actual args" do
-      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[subcommand with_args actual_argument]) }
+      output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(subcommand with_args actual_argument)) }
       expect(output.strip).to eql("received arguments: actual_argument")
     end
   end
@@ -186,8 +193,8 @@ describe ".register-ing a Thor subclass" do
     it "includes the plugin's subcommand name in subcommand's help" do
       begin
         $thor_runner = false
-        help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[exciting]) }
-        expect(help_output).to include("thor exciting_plugin_c_l_i fireworks")
+        help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(exciting)) }
+        expect(help_output).to include("thor exciting fireworks")
       ensure
         $thor_runner = true
       end
@@ -196,12 +203,12 @@ describe ".register-ing a Thor subclass" do
 
   context "when hidden" do
     it "omits the hidden plugin's usage from the help" do
-      help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[help]) }
+      help_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(help)) }
       expect(help_output).not_to include("secret stuff")
     end
 
     it "registers the plugin as a subcommand" do
-      secret_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[secret squirrel]) }
+      secret_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(secret squirrel)) }
       expect(secret_output).to eq("I love nuts\n")
     end
   end
@@ -209,19 +216,19 @@ end
 
 describe ".register-ing a Thor::Group subclass" do
   it "registers the group as a single command" do
-    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[groupwork]) }
+    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(groupwork)) }
     expect(group_output).to eq("part one\npart two\n")
   end
 end
 
 describe "1.8 and 1.9 syntax compatibility" do
   it "is compatible with both 1.8 and 1.9 syntax w/o command options" do
-    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[zoo]) }
+    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(zoo)) }
     expect(group_output).to match(/zebra/)
   end
 
   it "is compatible with both 1.8 and 1.9 syntax w/command options" do
-    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w[zoo -w lion]) }
+    group_output = capture(:stdout) { BoringVendorProvidedCLI.start(%w(zoo -w lion)) }
     expect(group_output).to match(/lion/)
   end
 end
